@@ -4,6 +4,7 @@ from BotCore import DataBase
 from BotCore.ModelInfo import ModelInfo
 
 
+# noinspection SqlNoDataSourceInspection,SqlResolve
 class DAO:
 
 	def __init__(self, database: DataBase, model: Type[ModelInfo]):
@@ -22,3 +23,10 @@ class DAO:
 
 	def getall(self):
 		return self.database.fetchall(f"SELECT {', '.join(self.model.fields())} FROM {self.model.table()}")
+
+	def find_by_id(self, row_id):
+		return self.database.fetchone(
+			f"SELECT {', '.join(self.model.fields())} "
+			f"FROM {self.model.table()} "
+			f"WHERE id = ?", row_id
+		)
