@@ -1,8 +1,10 @@
 
 from typing import TypeVar, Type, Generic
 
-T = TypeVar("T")
-D = TypeVar("D")
+from BotCore import DAO, ModelInfo
+
+T = TypeVar("T", bound=type(ModelInfo))
+D = TypeVar("D", bound=type(DAO))
 
 
 class Service(Generic[T, D]):
@@ -20,6 +22,9 @@ class Service(Generic[T, D]):
 	def getall(self) -> list[T]:
 		return self.dao.getall()
 
+	def find_by_id(self, row_id):
+		return self.dao.find_by_id(row_id)
+
 	def to_objects(self, rows: list[tuple]) -> list[T]:
 		return [self.to_object(row) for row in rows]
 
