@@ -3,4 +3,6 @@ from .Bot import Bot
 from .Controller import Controller
 from .Handlers import message_handler, callback_query_handler
 from .Service import Service
+from .DAO import DAO
+from .ModelInfo import ModelInfo
 from .DataBase import DataBase
